
# q-expansion of newform 2640.2.d.j, downloaded from the LMFDB on 27 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 2640
weight = 2
poly_data = [32, 128, 256, 72, 0, -8, 49, 0, 0, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[32166696, 12488920, -2044028, -6611696, 14958820, -2839095, 24444, -81760, 324324, -54999], 12684472], [[25494888, -13066904, -3939292, -12697712, 16190470, -5421519, 47804, -174424, 340038, -107559], 12684472], [[61866384, -438304, -4523300, -14586768, 22276486, -6232689, 54788, -197784, 432702, -123273], 12684472], [[6907940, 25739600, 4462776, 615825, -2125188, 5119783, -46332, 7857, -26280, 104247], 6342236], [[-4763984, 6766076, 3994340, 12586640, -5793430, 5172705, -52980, 286180, -81794, 119205], 6342236], [[-3682456, -16234214, -8262046, 4863106, 1930637, -4875854, 47328, 125028, 23149, -106488], 3171118], [[16646604, 67943588, 28790394, -1871757, -5622889, 13781201, 227626, -33057, -69237, 280621], 6342236], [[19982508, 68037028, 29738026, 1171251, -6238714, 15072413, 215946, 13275, -77094, 306901], 6342236], [[37370424, 138820152, 48520958, -24282, -11998453, 29140550, 88630, -9486, -148077, 593362], 6342236]]

hecke_ring_character_values = [[991, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [661, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [881, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1057, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1201, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -1, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 1, 0, -1, 0, 1, 0], [0, -2, 2, 0, -2, 0, 0, 1, 1, -1], [0, 1, 1, -2, 0, 0, 0, 1, -1, 0], [0, 0, 0, 0, -1, 0, 1, 1, 0, -1], [-3, 0, -1, -1, 0, -1, 0, 1, -1, 0], [-1, 1, 0, 1, 0, -1, 0, -2, 2, 0], [0, -1, 1, 0, -2, 0, 0, 1, 1, 0], [-1, -1, -2, 1, 0, -1, 0, 0, 0, 0], [0, 2, -2, 0, 1, 0, -1, -1, 0, 2], [0, 0, 0, 0, -3, 0, -1, 1, 2, -1], [0, -1, 1, 0, 2, 0, 2, 2, 0, -2], [5, -1, 0, 1, 0, 1, 0, 2, -2, 0], [-1, 0, -1, 1, 0, -1, 0, 2, -2, 0], [0, 1, -1, 0, -2, 0, 0, 1, 1, -2], [-2, 1, 1, -2, 0, 0, 0, 4, -4, 0], [0, -2, 2, 0, 4, 0, 0, 1, 1, 1], [7, -1, 0, 1, 0, 1, 0, -1, 1, 0], [0, -1, 1, 0, 2, 0, 0, 2, 2, -1], [3, -1, 0, -1, 0, 1, 0, -2, 2, 0], [0, 3, -3, 0, 2, 0, 0, 1, 1, 2], [5, -2, 1, 3, 0, 3, 0, -1, 1, 0], [0, 0, 0, 0, -2, 0, -2, 0, 2, 0], [0, -2, 2, 0, -2, 0, 2, 3, 1, 1], [-5, 0, -1, 1, 0, -1, 0, -2, 2, 0], [0, -1, 1, 0, 1, 0, -1, -3, -2, 3], [0, 2, -2, 0, 4, 0, 0, -4, -4, 5], [-6, 1, 1, -2, 0, 0, 0, -1, 1, 0], [0, -3, 3, 0, 1, 0, -1, -1, 0, 1], [2, 3, 1, 0, 0, -2, 0, 1, -1, 0], [-7, 0, -1, -1, 0, -1, 0, 3, -3, 0], [-7, 1, 0, -1, 0, -1, 0, 1, -1, 0], [0, 1, -1, 0, -6, 0, 0, 1, 1, -4], [0, -2, 2, 0, 8, 0, 0, 0, 0, -2], [0, -5, 5, 0, -6, 0, 0, 0, 0, -1], [0, -1, 1, 0, 4, 0, 0, 0, 0, -1], [10, 2, 0, -2, 0, -2, 0, 2, -2, 0], [-1, -1, 0, 1, 0, 1, 0, 2, -2, 0], [-3, -2, -3, 1, 0, -1, 0, 0, 0, 0], [0, 0, 0, 0, 2, 0, 2, 5, 3, -1], [0, 1, -1, 0, 4, 0, 0, 0, 0, 1], [0, -2, -2, 0, 0, 0, 0, -4, 4, 0], [-8, -3, 1, -2, 0, 4, 0, 3, -3, 0], [0, 0, 0, 0, 2, 0, 2, -2, -4, 0], [0, 2, -2, 0, -10, 0, -2, 1, 3, 3], [-8, 4, 6, -2, 0, 2, 0, 4, -4, 0], [0, 3, -3, 0, 12, 0, 0, 0, 0, 1], [14, -4, -6, 6, 0, -2, 0, -4, 4, 0], [0, 0, 2, -6, 0, 2, 0, 4, -4, 0], [1, -7, -6, 1, 0, 1, 0, 0, 0, 0], [0, -1, 1, 0, 9, 0, 3, 5, 2, -1], [0, -1, 1, 0, 8, 0, -2, -2, 0, -3], [-3, -2, -1, -1, 0, 1, 0, -6, 6, 0], [-5, 5, 6, -3, 0, 1, 0, -1, 1, 0], [0, 4, -4, 0, -5, 0, 1, 0, -1, 4], [3, -4, -3, 1, 0, 1, 0, -5, 5, 0], [0, -4, 4, 0, -5, 0, 1, 5, 4, -8], [0, -1, 1, 0, -2, 0, -2, 4, 6, -1], [0, -6, 6, 0, -9, 0, 1, 3, 2, -6], [-14, -1, -1, -2, 0, 0, 0, -4, 4, 0], [0, 2, -2, 0, 10, 0, 2, 0, -2, 4], [0, 5, -5, 0, 6, 0, -2, -6, -4, 4], [-3, 4, -1, -5, 0, -5, 0, 3, -3, 0], [0, 0, 0, 0, -4, 0, 0, 1, 1, -1], [0, -1, 1, 0, -18, 0, 0, 0, 0, 1], [-5, 0, -1, 5, 0, -1, 0, -4, 4, 0], [0, 1, -1, 0, 1, 0, -1, -3, -2, -3], [10, 2, 4, 2, 0, 2, 0, 2, -2, 0], [0, -4, 4, 0, 10, 0, 2, 2, 0, -4], [0, -6, 6, 0, 7, 0, 1, -2, -3, -4], [-6, 1, 1, -2, 0, 0, 0, 3, -3, 0], [0, -6, 6, 0, 11, 0, 1, -3, -4, -3], [-11, 4, 5, -1, 0, 1, 0, 6, -6, 0], [0, -1, 1, 0, -12, 0, 2, 1, -1, -4], [1, -5, -6, -3, 0, -1, 0, -2, 2, 0], [-16, 0, 2, 2, 0, 2, 0, 0, 0, 0], [-2, -2, 0, -6, 0, 2, 0, 2, -2, 0], [5, -3, 0, 3, 0, 3, 0, -4, 4, 0], [4, -6, -2, 4, 0, 4, 0, -2, 2, 0], [0, 2, -2, 0, -10, 0, -2, -2, 0, -2], [-9, -1, 0, 5, 0, 1, 0, -5, 5, 0], [0, 0, 0, 0, 18, 0, -2, 0, 2, 0], [7, 1, -2, 3, 0, -3, 0, -2, 2, 0], [0, 2, -2, 0, 6, 0, -2, -5, -3, 7], [13, 0, -5, 3, 0, -5, 0, -9, 9, 0], [0, 0, 0, 0, -4, 0, 0, -4, -4, 2], [0, 0, 0, 0, -16, 0, 0, 4, 4, -8], [6, -2, 0, -6, 0, 2, 0, 4, -4, 0], [0, 2, -2, 0, 8, 0, 0, -4, -4, 0], [2, 4, 2, 2, 0, -2, 0, -2, 2, 0], [-4, 3, 1, 4, 0, -2, 0, 7, -7, 0], [0, -3, 3, 0, -2, 0, -4, -4, 0, 1], [-7, -4, 1, -1, 0, 5, 0, -4, 4, 0], [-3, 1, 0, -7, 0, -1, 0, 8, -8, 0], [0, 0, 0, 0, 13, 0, -1, -1, 0, 0], [3, 2, 1, -11, 0, -1, 0, 4, -4, 0], [0, 6, -6, 0, 5, 0, -5, 1, 6, 2], [0, -5, 5, 0, 6, 0, -2, 4, 6, -5], [0, -4, 4, 0, 12, 0, -4, 1, 5, -5], [-1, -4, -3, -3, 0, 1, 0, 3, -3, 0], [4, 3, -1, 2, 0, -4, 0, -1, 1, 0], [0, -7, 7, 0, -6, 0, 0, 5, 5, 0], [0, -2, 2, 0, -22, 0, 2, 0, -2, -2], [0, -4, 4, 0, 10, 0, 0, 1, 1, 5], [-5, 2, 3, -1, 0, 1, 0, -4, 4, 0], [10, -2, -2, 0, 0, 0, 0, -6, 6, 0], [0, 6, -6, 0, 12, 0, 0, 0, 0, -3], [0, 2, -2, 0, 15, 0, 5, 2, -3, 4], [0, 3, -3, 0, 5, 0, 3, -3, -6, 3], [-1, -3, 4, -3, 0, 7, 0, -2, 2, 0], [2, -4, -2, -6, 0, 2, 0, 2, -2, 0], [-5, -3, -2, 3, 0, 1, 0, -10, 10, 0], [0, 7, -7, 0, 0, 0, 2, 1, -1, -2], [0, -2, 2, 0, -3, 0, -1, -5, -4, -1], [0, -1, 1, 0, -14, 0, 2, 8, 6, -4], [4, 0, 0, 8, 0, 0, 0, -12, 12, 0], [-8, 2, 0, 2, 0, -2, 0, 6, -6, 0], [0, -4, 4, 0, 14, 0, 2, 5, 3, -9], [0, 1, -1, 0, 6, 0, 2, -2, -4, -7], [0, 2, -2, 0, 6, 0, 2, 2, 0, 0], [20, 4, 4, -4, 0, 0, 0, 0, 0, 0], [1, -4, 3, -5, 0, 7, 0, 3, -3, 0], [-1, -7, -6, -3, 0, 1, 0, 0, 0, 0], [-17, 2, -1, -5, 0, -3, 0, -4, 4, 0], [0, -10, 10, 0, 2, 0, -2, 0, 2, -2], [0, -2, 2, 0, 3, 0, -3, -2, 1, 4], [6, -1, -3, -8, 0, -2, 0, 3, -3, 0], [0, 1, -1, 0, 0, 0, 6, -2, -8, 1], [-8, 4, 8, -8, 0, 4, 0, 0, 0, 0], [0, -1, 1, 0, 2, 0, 0, -3, -3, 0], [5, 0, 3, -1, 0, 3, 0, 5, -5, 0], [18, -4, -4, 8, 0, 0, 0, -6, 6, 0], [0, 7, -7, 0, 0, 0, -4, -2, 2, 2], [0, 2, -2, 0, -1, 0, 1, 1, 0, 6], [0, -1, 1, 0, 16, 0, 4, -4, -8, 6], [-3, -3, -2, -1, 0, 1, 0, 0, 0, 0], [-8, -3, -3, -2, 0, 0, 0, 3, -3, 0], [1, 2, 1, -5, 0, -1, 0, 11, -11, 0], [0, 2, -2, 0, 16, 0, 0, 4, 4, -2], [0, 7, -7, 0, -22, 0, -4, 4, 8, 1], [-11, -5, -2, 7, 0, 3, 0, -2, 2, 0], [18, 1, -3, -2, 0, -4, 0, 0, 0, 0], [0, -8, 8, 0, -1, 0, -3, -4, -1, -4], [0, -1, 1, 0, 2, 0, -2, 0, 2, -1], [-29, -2, -1, 5, 0, 1, 0, -5, 5, 0], [0, 2, -2, 0, 3, 0, 1, 5, 4, -3], [0, 4, -4, 0, -7, 0, -1, -4, -3, 0], [-8, 0, 2, 2, 0, 2, 0, -6, 6, 0], [0, 1, -1, 0, 8, 0, -2, -3, -1, -8], [0, 7, -7, 0, 0, 0, 2, 0, -2, -3], [0, -1, 1, 0, 2, 0, 0, 1, 1, 0], [3, 0, -3, 3, 0, -3, 0, 0, 0, 0], [-5, -1, -4, -3, 0, -3, 0, -1, 1, 0], [6, 0, -4, -8, 0, -4, 0, 2, -2, 0], [0, 4, -4, 0, -12, 0, 0, 3, 3, -3], [-13, 6, 3, -3, 0, -3, 0, -7, 7, 0], [0, 4, -4, 0, -20, 0, 0, 6, 6, 2], [0, -5, 5, 0, 16, 0, 8, 0, -8, 5], [0, -2, 2, 0, 2, 0, -6, -2, 4, 3], [0, -4, 0, 0, 0, 4, 0, -2, 2, 0], [0, -7, 7, 0, 3, 0, 1, 7, 6, -13], [0, -2, 2, 0, 5, 0, -1, -1, 0, -1], [21, -7, -6, 3, 0, 1, 0, 4, -4, 0], [0, -4, 4, 0, 5, 0, 3, 8, 5, 4], [-2, -4, 4, 4, 0, 8, 0, 2, -2, 0], [0, 7, -7, 0, 10, 0, 6, 4, -2, 6], [-8, -1, 5, 0, 0, 6, 0, 11, -11, 0], [1, 7, 10, -5, 0, 3, 0, -4, 4, 0], [-4, -4, 0, 4, 0, 4, 0, -6, 6, 0], [0, 6, -6, 0, 32, 0, 0, -5, -5, 3], [-37, 5, 4, -7, 0, -1, 0, -2, 2, 0], [12, 8, 2, 2, 0, -6, 0, 6, -6, 0], [8, -1, 7, -10, 0, 8, 0, -1, 1, 0], [17, 2, 3, -1, 0, 1, 0, 2, -2, 0], [0, -2, 2, 0, 12, 0, -8, 4, 12, -1], [-39, 4, 1, -5, 0, -3, 0, 0, 0, 0], [0, 6, -6, 0, 12, 0, 4, 6, 2, 0], [2, -5, -9, -2, 0, -4, 0, 1, -1, 0], [0, 3, -3, 0, -14, 0, 0, 5, 5, 0], [0, -7, 7, 0, -2, 0, 2, 8, 6, 1], [0, 8, -8, 0, 19, 0, -7, -9, -2, 9], [20, 1, 9, -4, 0, 8, 0, 0, 0, 0], [0, 4, -4, 0, 25, 0, 3, 0, -3, 0], [0, -1, 1, 0, -14, 0, -8, -7, 1, 8], [-18, 2, 2, -8, 0, 0, 0, 0, 0, 0], [-2, 4, 2, -14, 0, -2, 0, 6, -6, 0], [0, 9, -9, 0, -8, 0, -2, -3, -1, 2], [0, 5, -5, 0, 14, 0, 4, 4, 0, -1], [8, 3, -3, 8, 0, -6, 0, -1, 1, 0], [5, 4, 5, -1, 0, 1, 0, 2, -2, 0], [0, -4, 4, 0, -20, 0, -4, -13, -9, 1], [0, -5, 5, 0, -5, 0, -3, 5, 8, -7], [30, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -5, 5, 0, 16, 0, 2, -3, -5, 4], [0, -3, 3, 0, -4, 0, -4, 0, 4, -1], [0, 7, -7, 0, 10, 0, 4, 2, -2, 7], [7, 6, 3, 9, 0, -3, 0, 11, -11, 0], [19, -7, -6, 1, 0, 1, 0, -1, 1, 0], [0, -1, 1, 0, -36, 0, -2, 1, 3, 4], [-12, 0, 2, -6, 0, 2, 0, 18, -18, 0], [-24, 2, -6, 0, 0, -8, 0, 4, -4, 0], [0, 13, -13, 0, 8, 0, -8, -6, 2, 10], [2, -4, -6, -2, 0, -2, 0, -12, 12, 0], [0, -1, 1, 0, 24, 0, 2, 4, 2, -1], [3, -4, 1, 1, 0, 5, 0, -5, 5, 0], [33, -3, -2, -9, 0, 1, 0, 4, -4, 0], [0, -6, 6, 0, -6, 0, 2, -1, -3, 3], [-8, 11, 7, -8, 0, -4, 0, 8, -8, 0], [0, -2, 2, 0, -32, 0, 0, -2, -2, -4], [0, -6, 6, 0, -20, 0, -8, -2, 6, -8], [-26, 2, 0, 14, 0, -2, 0, -10, 10, 0], [12, 1, -3, 10, 0, -4, 0, -15, 15, 0], [0, 0, 0, 0, 0, 0, 0, 4, 4, 3], [-9, 2, -5, 13, 0, -7, 0, 1, -1, 0], [0, 10, -10, 0, -7, 0, -9, -3, 6, 1], [0, 11, -11, 0, 10, 0, 2, -4, -6, 12], [-3, 0, 5, -1, 0, 5, 0, 2, -2, 0], [-7, 3, 2, -9, 0, -1, 0, 15, -15, 0], [38, -2, 2, -4, 0, 4, 0, 4, -4, 0], [0, -6, 6, 0, -4, 0, 4, 12, 8, -2], [0, 0, 0, 0, -16, 0, 4, -3, -7, 3], [3, 2, -7, 5, 0, -9, 0, -2, 2, 0], [0, -3, 3, 0, -3, 0, -1, -11, -10, -3], [-4, -3, -1, 0, 0, 2, 0, 0, 0, 0], [0, -4, 4, 0, -10, 0, -6, -2, 4, -5], [22, 0, 2, -2, 0, 2, 0, -2, 2, 0], [0, -11, 11, 0, -20, 0, 2, 9, 7, -12], [-10, -13, -11, 4, 0, 2, 0, -5, 5, 0], [1, 5, 8, 3, 0, 3, 0, 11, -11, 0], [-25, 0, 1, 1, 0, 1, 0, 7, -7, 0], [0, 6, -6, 0, 26, 0, -2, -10, -8, 6], [0, -5, 5, 0, 2, 0, 0, 12, 12, -7], [13, -1, -6, 3, 0, -5, 0, -6, 6, 0], [0, 9, -9, 0, 10, 0, -10, -2, 8, 3], [41, 3, 8, 1, 0, 5, 0, -10, 10, 0], [-7, 0, -1, 1, 0, -1, 0, 4, -4, 0], [0, -4, 4, 0, -4, 0, -4, 6, 10, -6], [10, -1, -7, 0, 0, -6, 0, -5, 5, 0], [0, -12, 12, 0, -12, 0, 0, -4, -4, 0], [17, -11, -8, 15, 0, 3, 0, -10, 10, 0], [0, -4, 4, 0, -2, 0, -8, -5, 3, 7], [-10, 6, 4, 2, 0, -2, 0, 6, -6, 0], [0, -8, 8, 0, 16, 0, -4, -2, 2, 4], [13, -7, -10, 5, 0, -3, 0, -14, 14, 0], [6, 1, 3, 4, 0, 2, 0, 3, -3, 0], [0, 11, -11, 0, 16, 0, -2, -12, -10, 5], [0, -2, 2, 0, 9, 0, -1, -8, -7, 6], [-13, -3, 4, -11, 0, 7, 0, 14, -14, 0], [0, 14, -14, 0, 25, 0, 7, 5, -2, 9], [-12, -7, -3, 14, 0, 4, 0, -11, 11, 0], [0, 1, -1, 0, -30, 0, 2, 4, 2, -7], [24, -1, 1, 4, 0, 2, 0, 7, -7, 0], [-13, -3, -6, 1, 0, -3, 0, 6, -6, 0], [0, 2, -2, 0, 7, 0, 9, 3, -6, 4], [0, 11, -11, 0, 4, 0, -4, -2, 2, -2], [0, -12, 12, 0, -6, 0, 2, -3, -5, -1], [0, 4, -4, 0, -16, 0, 0, 4, 4, -3], [0, 15, -15, 0, 12, 0, 2, 6, 4, 1], [-5, 14, 13, -11, 0, -1, 0, 10, -10, 0], [0, -8, 8, 0, -9, 0, 5, -6, -11, -2], [0, 3, -3, 0, 7, 0, -3, -3, 0, -1], [-18, 4, 6, 2, 0, 2, 0, -10, 10, 0], [14, -5, -3, 10, 0, 2, 0, 2, -2, 0], [16, 4, 2, 6, 0, -2, 0, -18, 18, 0], [0, 0, 0, 0, 27, 0, -7, -5, 2, 4], [0, 9, -9, 0, -18, 0, 6, 0, -6, 3], [-20, 10, 4, -10, 0, -6, 0, -2, 2, 0], [0, -1, 1, 0, -58, 0, -4, 1, 5, -8], [0, -3, 3, 0, -8, 0, 6, 1, -5, -6], [-41, 1, 6, 1, 0, 5, 0, 3, -3, 0], [0, -4, 4, 0, 24, 0, 0, 11, 11, -3], [0, 0, 0, 0, 12, 0, 0, -2, -2, 4], [0, 12, -12, 0, -16, 0, -4, -2, 2, 10], [23, -6, 1, 5, 0, 7, 0, 2, -2, 0], [16, 2, 4, -2, 0, 2, 0, 4, -4, 0], [-14, 2, 8, -10, 0, 6, 0, 8, -8, 0], [0, -3, 3, 0, -20, 0, -6, 4, 10, -7], [7, 3, 14, -19, 0, 11, 0, 2, -2, 0], [0, -1, 1, 0, -8, 0, 6, 2, -4, -9], [19, -4, -5, -11, 0, -1, 0, 8, -8, 0], [0, 8, -8, 0, -9, 0, -3, -5, -2, -4], [-11, 2, 9, -7, 0, 7, 0, 16, -16, 0], [0, -1, 1, 0, -30, 0, -8, -3, 5, 2], [0, 7, -7, 0, 12, 0, 8, 12, 4, -5], [-15, 7, 8, 3, 0, 1, 0, -4, 4, 0], [13, -2, 1, -5, 0, 3, 0, 15, -15, 0], [-3, -4, 5, -9, 0, 9, 0, 2, -2, 0], [0, 18, -18, 0, 22, 0, -2, -10, -8, 8], [0, 6, -6, 0, 4, 0, -2, 9, 11, 1], [-24, 0, 4, 4, 0, 4, 0, -8, 8, 0], [0, -4, 4, 0, 7, 0, -3, -10, -7, 6], [-25, 12, 13, -11, 0, 1, 0, 5, -5, 0], [20, 4, 4, -4, 0, 0, 0, 10, -10, 0], [0, 9, -9, 0, -20, 0, 0, 2, 2, 6], [-18, 15, 11, -2, 0, -4, 0, -11, 11, 0], [0, -16, 16, 0, -21, 0, 1, -1, -2, -6], [0, -2, 2, 0, 2, 0, -6, -11, -5, 13], [0, -7, 7, 0, -4, 0, -4, -6, -2, -11], [-5, 11, 12, -19, 0, 1, 0, 17, -17, 0]]
